From bdc2b7513d0ff574ffa63a8d5fb445915088c265 Mon Sep 17 00:00:00 2001
From: Cyril Brulebois <kibi@debian.org>
Date: Wed, 18 Mar 2020 18:25:49 +0100
Subject: [PATCH] attempt1

---
 slaves/lint_po | 27 +++++++++++++++++++++++++--
 1 file changed, 25 insertions(+), 2 deletions(-)

diff --git a/slaves/lint_po b/slaves/lint_po
index af7bd35..34bea7c 100755
--- a/slaves/lint_po
+++ b/slaves/lint_po
@@ -34,6 +34,7 @@ import itertools
 import logging
 import multiprocessing
 import os.path
+import pathlib
 import re
 import shutil
 import subprocess
@@ -324,9 +325,31 @@ def main(logger) -> None:
             # As we start 10 i18nspector instances, we run into a race
             # condition, as all try to create $XDG_CACHE_HOME/rply, that's why
             # we check the file before the others. see #17359#note-14
+            #
+            # The first item doesn't necessarily needs that cache, so run
+            # sequentially (until a hard limit) until a file appears in the
+            # cache directory, see #17359#note-24
+            chain = []
             iterator = iter(files)
-            chain = [(_check_po_file(next(iterator)),),
-                     pool.imap_unordered(_check_po_file,iterator, 10)]
+
+            # Handle the head...
+            max_attempts = 10
+            rply_cache = []
+            for attempt in range(max_attempts):
+                chain.append(_check_po_file(next(iterator)),)
+                rply_cache = sorted(pathlib.Path(tmpXDGCacheHome).glob('**/*.jsox'))
+                if rply_cache:
+                    logger.info("rply cache is hot after attempt number {attempt}/{max}"
+                                .format(attempt=attempt+1, max=max_attempts))
+                    break
+
+            # breaking hard if needed:
+            if not rply_cache:
+                sys.exit("rply cache still not hot after {max} attempts, please"
+                         " investigate (see #17359#note-24)".format(max=max_attempts))
+
+            # Handle the tail:
+            chain.extend(pool.imap_unordered(_check_po_file,iterator, 10))
 
             for fname, issues in itertools.chain.from_iterable(chain):
                 if issues:
-- 
2.11.0

